utils
=====

In this module there are several utilities used by the WeatherDB package, you shouldn't need to use them directly.

.. autoclass:: weatherdb.utils.TimestampPeriod

dwd
---
.. automodule:: weatherdb.utils.dwd

geometry
--------
.. automodule:: weatherdb.utils.geometry

get_data
--------
.. automodule:: weatherdb.utils.get_data

logging
-------
.. automodule:: weatherdb.utils.logging
